@@ -5,11 +5,11 @@
 Office
 </category>
 
-<name>  
+<name>
 Adobe Reader
 </name>
 
-<description>  
+<description>
 Adobe Reader PDF viewer
 </description>
 
@@ -21,9 +21,9 @@ all
 
 <preinstall>
 gpg --keyserver keyserver.ubuntu.com --recv-keys 5C808C2B65558117
-gpg --armor --export 5C808C2B65558117 | apt-key add -  
-echo "deb http://www.deb-multimedia.org/ jessie main non-free">/etc/apt/sources.list.d/debmulti.list
-x-terminal-emulator -e apt-get update
+gpg --armor --export 5C808C2B65558117 | apt-key add -
+echo "deb http://www.deb-multimedia.org/ buster main non-free">/etc/apt/sources.list.d/mxpitemp.list
+apt-get update
 </preinstall>
 
 <install_package_names>
@@ -33,8 +33,8 @@ acroread-plugins
 
 
 <postinstall>
-rm -f /etc/apt/sources.list.d/debmulti.list
-x-terminal-emulator -e apt-get update
+rm -f /etc/apt/sources.list.d/mxpitemp.list
+apt-get update
 </postinstall>
 
 
@@ -42,4 +42,4 @@ x-terminal-emulator -e apt-get update
 acroread
 acroread-plugins
 </uninstall_package_names>
-</app>
\ No newline at end of file
+</app>
